@@ -3,7 +3,7 @@ BEGIN {
   $Data::DPath::Context::AUTHORITY = 'cpan:SCHWIGON';
 }
 # ABSTRACT: Abstraction for a current context that enables incremental searches
-$Data::DPath::Context::VERSION = '0.52';
+$Data::DPath::Context::VERSION = '0.53';
 use strict;
 use warnings;
 
@@ -16,7 +16,7 @@ use Data::DPath::Filters;
 use Iterator::Util;
 use List::Util 'min';
 #use Sys::CPU;
-use POSIX;
+use POSIX ();
 use Safe;
 
 # run filter expressions in own Safe.pm compartment
@@ -30,7 +30,7 @@ BEGIN {
 BEGIN {
   $Data::DPath::Filters::AUTHORITY = 'cpan:SCHWIGON';
 }
-$Data::DPath::Filters::VERSION = '0.52';
+$Data::DPath::Filters::VERSION = '0.53';
         $COMPARTMENT = Safe->new;
         $COMPARTMENT->permit(qw":base_core");
         # map DPath filter functions into new namespace
@@ -77,7 +77,7 @@ sub _splice_threads {
     return [[]] unless $nr_cargo;
 
     my $threadcount = $THREADCOUNT || 1;
-    my $blocksize   = ceil ($nr_cargo / $threadcount);
+    my $blocksize   = POSIX::ceil ($nr_cargo / $threadcount);
 
     my @result = map {
         my $first =  $_ * $blocksize;
